@@ -1,46 +1,83 @@
 /*
 	File:		MBCController.h
 	Contains:	Managing the entire user interface
-	Copyright:	 2002-2003 Apple Computer, Inc. All rights reserved.
+	Version:	1.0
+	Copyright:	 2002 by Apple Computer, Inc., all rights reserved.
 
-	IMPORTANT: This Apple software is supplied to you by Apple Computer,
-	Inc.  ("Apple") in consideration of your agreement to the following
-	terms, and your use, installation, modification or redistribution of
-	this Apple software constitutes acceptance of these terms.  If you do
-	not agree with these terms, please do not use, install, modify or
-	redistribute this Apple software.
-	
-	In consideration of your agreement to abide by the following terms,
-	and subject to these terms, Apple grants you a personal, non-exclusive
-	license, under Apple's copyrights in this original Apple software (the
-	"Apple Software"), to use, reproduce, modify and redistribute the
-	Apple Software, with or without modifications, in source and/or binary
-	forms; provided that if you redistribute the Apple Software in its
-	entirety and without modifications, you must retain this notice and
-	the following text and disclaimers in all such redistributions of the
-	Apple Software.  Neither the name, trademarks, service marks or logos
-	of Apple Computer, Inc. may be used to endorse or promote products
-	derived from the Apple Software without specific prior written
-	permission from Apple.  Except as expressly stated in this notice, no
-	other rights or licenses, express or implied, are granted by Apple
-	herein, including but not limited to any patent rights that may be
-	infringed by your derivative works or by other works in which the
-	Apple Software may be incorporated.
-	
-	The Apple Software is provided by Apple on an "AS IS" basis.  APPLE
-	MAKES NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION
-	THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND
-	FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE APPLE SOFTWARE OR ITS
-	USE AND OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
-	
-	IN NO EVENT SHALL APPLE BE LIABLE FOR ANY SPECIAL, INDIRECT,
-	INCIDENTAL OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-	PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
-	REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE APPLE SOFTWARE,
-	HOWEVER CAUSED AND WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING
-	NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN IF APPLE HAS BEEN
-	ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+	File Ownership:
+
+		DRI:				Matthias Neeracher    x43683
+
+	Writers:
+
+		(MN)	Matthias Neeracher
+
+	Change History (most recent first):
+
+		$Log: MBCController.h,v $
+		Revision 1.21  2004/08/16 07:49:23  neerache
+		Support flexible voices, weaker levels, accessibility
+		
+		Revision 1.20  2003/07/07 08:46:52  neerache
+		Localize Style Names
+		
+		Revision 1.19  2003/07/03 08:12:51  neerache
+		Use sheets for saving (RADAR 3093283)
+		
+		Revision 1.18  2003/07/03 03:19:15  neerache
+		Logarithmic time control, more UI tweaks
+		
+		Revision 1.17  2003/07/02 21:06:16  neerache
+		Move about box into separate class/nib
+		
+		Revision 1.16  2003/06/30 05:16:30  neerache
+		Transfer move execution to Controller
+		
+		Revision 1.15  2003/06/16 02:18:03  neerache
+		Implement floating board
+		
+		Revision 1.14  2003/06/04 23:14:05  neerache
+		Neater manipulation widget; remove obsolete graphics options
+		
+		Revision 1.13  2003/06/02 04:21:17  neerache
+		Remove gameEnd:, fUseLight
+		
+		Revision 1.12  2003/05/27 03:13:57  neerache
+		Rework game loading/saving code
+		
+		Revision 1.11  2003/05/24 20:29:25  neerache
+		Add Game Info Window
+		
+		Revision 1.10  2003/04/24 23:22:02  neeri
+		Implement persistent preferences, tweak UI
+		
+		Revision 1.9  2003/04/10 23:03:16  neeri
+		Load positions
+		
+		Revision 1.8  2003/04/05 05:45:08  neeri
+		Add PGN export
+		
+		Revision 1.7  2003/04/02 18:21:09  neeri
+		Support saving games
+		
+		Revision 1.6  2003/03/28 01:31:07  neeri
+		Support hints, last move
+		
+		Revision 1.5  2002/12/04 02:26:28  neeri
+		Fix updating when style changes
+		
+		Revision 1.4  2002/10/15 22:49:40  neeri
+		Add support for texture styles
+		
+		Revision 1.3  2002/10/08 22:56:23  neeri
+		Engine logging, color preferences
+		
+		Revision 1.2  2002/09/12 17:55:18  neeri
+		Introduce level controls
+		
+		Revision 1.1  2002/08/22 23:47:06  neeri
+		Initial Checkin
+		
 */
 
 #import <Cocoa/Cocoa.h>
@@ -51,6 +88,7 @@
 @class MBCBoardView;
 @class MBCEngine;
 @class MBCInteractivePlayer;
+@class NSSpeechSynthesizer;
 
 @interface MBCController : NSObject
 {
@@ -68,8 +106,12 @@
 	IBOutlet id		fLicense;
 	IBOutlet id		fGameInfo;
 	IBOutlet id 	fOpaqueView;
+	IBOutlet id		fComputerVoice;
+	IBOutlet id		fAlternateVoice;
+#if HAS_FLOATING_BOARD
 	IBOutlet id 	fFloatingView;
 	IBOutlet id		fFloatingMenuItem;
+#endif
 
 	MBCBoard *				fBoard;
 	MBCBoardView *			fView;
@@ -84,6 +126,8 @@
 	NSDictionary *			fLastLoad;
 	NSString *				fLastSaved;
 	NSMutableDictionary * 	fStyleLocMap;
+	NSSpeechSynthesizer *	fDefaultSynth;
+	NSSpeechSynthesizer *	fAlternateSynth;
 }
 
 + (MBCController *)controller;
@@ -105,7 +149,11 @@
 - (IBAction) saveGame:(id)sender;
 - (IBAction) saveGameAs:(id)sender;
 - (IBAction) saveMoves:(id)sender;
+- (IBAction) updateVoices:(id)sender;
+
+#if HAS_FLOATING_BOARD
 - (IBAction) toggleFloating:(id)sender;
+#endif
 
 - (void) startNewGame;
 
@@ -128,6 +176,10 @@
 
 - (NSString *) localizedStyleName:(NSString *)name;
 
+- (NSSpeechSynthesizer *) defaultSynth;
+- (NSSpeechSynthesizer *) alternateSynth;
+- (void)loadVoiceMenu:(id)menu withSelectedVoice:(NSString *)voiceIdentifierToSelect;
+
 @end
 
 // Local Variables:
